.. Relaton documentation master file.


Overview
========

This library provides convenience units and data classes
for interacting with Relaton bibliographic data in Python.

.. toctree::
   :maxdepth: 2

   get-started
   ref/index
   glossary
   development
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
